@@ -863,7 +863,7 @@ static Pax_Functions pax_functions = {
 
 
 void
-initpax()
+initpax(void)
 {
     int i;
     PyObject * d, *m, *v;
