@@ -1,5 +1,5 @@
 /***********************************************************
-Copyright (C) 1994 Steen Lumholt.
+Copyright (C) 1994, 2001 Steen Lumholt.
 Copyright 1994-1995 by Stichting Mathematisch Centrum, Amsterdam,
 The Netherlands.
 
@@ -302,8 +302,7 @@ static PyObject *trbInCmd;
 
 
 static PyObject *
-Tkinter_Error(v)
-	PyObject *v;
+Tkinter_Error(PyObject *v)
 {
 	PyErr_SetString(Tkinter_TclError, Tkapp_Result(v));
 	return NULL;
@@ -321,8 +320,7 @@ Tkinter_Error(v)
 /* Millisecond sleep() for Unix platforms. */
 
 static void
-Sleep(milli)
-	int milli;
+Sleep(int milli)
 {
 	/* XXX Too bad if you don't have select(). */
 	struct timeval t;
@@ -336,9 +334,7 @@ Sleep(milli)
 
 
 static char *
-AsString(value, tmp)
-	PyObject *value;
-	PyObject *tmp;
+AsString(PyObject *value, PyObject *tmp)
 {
 	if (PyString_Check(value))
 		return PyString_AsString(value);
@@ -355,8 +351,7 @@ AsString(value, tmp)
 #define ARGSZ 64
 
 static char *
-Merge(args)
-	PyObject *args;
+Merge(PyObject *args)
 {
 	PyObject *tmp = NULL;
 	char *argvStore[ARGSZ];
@@ -428,8 +423,7 @@ Merge(args)
 
 
 static PyObject *
-Split(list)
-	char *list;
+Split(char *list)
 {
 	int argc;
 	char **argv;
@@ -474,8 +468,7 @@ Split(list)
 /**** Tkapp Object ****/
 
 int
-Tcl_AppInit(interp)
-	Tcl_Interp *interp;
+Tcl_AppInit(Tcl_Interp *interp)
 {
 	if (Tcl_Init(interp) == TCL_ERROR) {
 		PySys_WriteStderr("Tcl_Init error: %s\n", interp->result);
@@ -495,15 +488,11 @@ Tcl_AppInit(interp)
  * `tkMain.c'.
  */
 
-static void EnableEventHook(); /* Forward */
-static void DisableEventHook(); /* Forward */
+static void EnableEventHook(void); /* Forward */
+static void DisableEventHook(void); /* Forward */
 
 static TkappObject *
-Tkapp_New(screenName, baseName, className, interactive)
-	char *screenName;
-	char *baseName;
-	char *className;
-	int interactive;
+Tkapp_New(char *screenName, char *baseName, char *className, int interactive)
 {
 	TkappObject *v;
 	char *argv0;
@@ -558,9 +547,7 @@ Tkapp_New(screenName, baseName, className, interactive)
 /** Tcl Eval **/
 
 static PyObject *
-Tkapp_Call(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_Call(PyObject *self, PyObject *args)
 {
 	/* This is copied from Merge() */
 	PyObject *tmp = NULL;
@@ -672,9 +659,7 @@ Tkapp_Call(self, args)
 
 
 static PyObject *
-Tkapp_GlobalCall(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_GlobalCall(PyObject *self, PyObject *args)
 {
 	/* Could do the same here as for Tkapp_Call(), but this is not used
 	   much, so I can't be bothered.  Unfortunately Tcl doesn't export a
@@ -708,9 +693,7 @@ Tkapp_GlobalCall(self, args)
 }
 
 static PyObject *
-Tkapp_Eval(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_Eval(PyObject *self, PyObject *args)
 {
 	char *script;
 	PyObject *res = NULL;
@@ -731,9 +714,7 @@ Tkapp_Eval(self, args)
 }
 
 static PyObject *
-Tkapp_GlobalEval(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_GlobalEval(PyObject *self, PyObject *args)
 {
 	char *script;
 	PyObject *res = NULL;
@@ -754,9 +735,7 @@ Tkapp_GlobalEval(self, args)
 }
 
 static PyObject *
-Tkapp_EvalFile(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_EvalFile(PyObject *self, PyObject *args)
 {
 	char *fileName;
 	PyObject *res = NULL;
@@ -778,9 +757,7 @@ Tkapp_EvalFile(self, args)
 }
 
 static PyObject *
-Tkapp_Record(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_Record(PyObject *self, PyObject *args)
 {
 	char *script;
 	PyObject *res = NULL;
@@ -801,9 +778,7 @@ Tkapp_Record(self, args)
 }
 
 static PyObject *
-Tkapp_AddErrorInfo(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_AddErrorInfo(PyObject *self, PyObject *args)
 {
 	char *msg;
 
@@ -822,10 +797,7 @@ Tkapp_AddErrorInfo(self, args)
 /** Tcl Variable **/
 
 static PyObject *
-SetVar(self, args, flags)
-	PyObject *self;
-	PyObject *args;
-	int flags;
+SetVar(PyObject *self, PyObject *args, int flags)
 {
 	char *name1, *name2, *ok, *s;
 	PyObject *newValue;
@@ -866,17 +838,13 @@ SetVar(self, args, flags)
 }
 
 static PyObject *
-Tkapp_SetVar(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_SetVar(PyObject *self, PyObject *args)
 {
 	return SetVar(self, args, TCL_LEAVE_ERR_MSG);
 }
 
 static PyObject *
-Tkapp_GlobalSetVar(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_GlobalSetVar(PyObject *self, PyObject *args)
 {
 	return SetVar(self, args, TCL_LEAVE_ERR_MSG | TCL_GLOBAL_ONLY);
 }
@@ -884,10 +852,7 @@ Tkapp_GlobalSetVar(self, args)
 
 
 static PyObject *
-GetVar(self, args, flags)
-	PyObject *self;
-	PyObject *args;
-	int flags;
+GetVar(PyObject *self, PyObject *args, int flags)
 {
 	char *name1, *name2=NULL, *s;
 	PyObject *res = NULL;
@@ -911,17 +876,13 @@ GetVar(self, args, flags)
 }
 
 static PyObject *
-Tkapp_GetVar(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_GetVar(PyObject *self, PyObject *args)
 {
 	return GetVar(self, args, TCL_LEAVE_ERR_MSG);
 }
 
 static PyObject *
-Tkapp_GlobalGetVar(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_GlobalGetVar(PyObject *self, PyObject *args)
 {
 	return GetVar(self, args, TCL_LEAVE_ERR_MSG | TCL_GLOBAL_ONLY);
 }
@@ -929,10 +890,7 @@ Tkapp_GlobalGetVar(self, args)
 
 
 static PyObject *
-UnsetVar(self, args, flags)
-	PyObject *self;
-	PyObject *args;
-	int flags;
+UnsetVar(PyObject *self, PyObject *args, int flags)
 {
 	char *name1, *name2=NULL;
 	PyObject *res = NULL;
@@ -959,17 +917,13 @@ UnsetVar(self, args, flags)
 }
 
 static PyObject *
-Tkapp_UnsetVar(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_UnsetVar(PyObject *self, PyObject *args)
 {
 	return UnsetVar(self, args, TCL_LEAVE_ERR_MSG);
 }
 
 static PyObject *
-Tkapp_GlobalUnsetVar(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_GlobalUnsetVar(PyObject *self, PyObject *args)
 {
 	return UnsetVar(self, args, TCL_LEAVE_ERR_MSG | TCL_GLOBAL_ONLY);
 }
@@ -979,9 +933,7 @@ Tkapp_GlobalUnsetVar(self, args)
 /** Tcl to Python **/
 
 static PyObject *
-Tkapp_GetInt(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_GetInt(PyObject *self, PyObject *args)
 {
 	char *s;
 	int v;
@@ -994,9 +946,7 @@ Tkapp_GetInt(self, args)
 }
 
 static PyObject *
-Tkapp_GetDouble(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_GetDouble(PyObject *self, PyObject *args)
 {
 	char *s;
 	double v;
@@ -1009,9 +959,7 @@ Tkapp_GetDouble(self, args)
 }
 
 static PyObject *
-Tkapp_GetBoolean(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_GetBoolean(PyObject *self, PyObject *args)
 {
 	char *s;
 	int v;
@@ -1024,9 +972,7 @@ Tkapp_GetBoolean(self, args)
 }
 
 static PyObject *
-Tkapp_ExprString(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_ExprString(PyObject *self, PyObject *args)
 {
 	char *s;
 	PyObject *res = NULL;
@@ -1046,9 +992,7 @@ Tkapp_ExprString(self, args)
 }
 
 static PyObject *
-Tkapp_ExprLong(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_ExprLong(PyObject *self, PyObject *args)
 {
 	char *s;
 	PyObject *res = NULL;
@@ -1069,9 +1013,7 @@ Tkapp_ExprLong(self, args)
 }
 
 static PyObject *
-Tkapp_ExprDouble(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_ExprDouble(PyObject *self, PyObject *args)
 {
 	char *s;
 	PyObject *res = NULL;
@@ -1094,9 +1036,7 @@ Tkapp_ExprDouble(self, args)
 }
 
 static PyObject *
-Tkapp_ExprBoolean(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_ExprBoolean(PyObject *self, PyObject *args)
 {
 	char *s;
 	PyObject *res = NULL;
@@ -1119,9 +1059,7 @@ Tkapp_ExprBoolean(self, args)
 
 
 static PyObject *
-Tkapp_SplitList(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_SplitList(PyObject *self, PyObject *args)
 {
 	char *list;
 	int argc;
@@ -1153,9 +1091,7 @@ Tkapp_SplitList(self, args)
 }
 
 static PyObject *
-Tkapp_Split(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_Split(PyObject *self, PyObject *args)
 {
 	char *list;
 
@@ -1165,9 +1101,7 @@ Tkapp_Split(self, args)
 }
 
 static PyObject *
-Tkapp_Merge(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_Merge(PyObject *self, PyObject *args)
 {
 	char *s = Merge(args);
 	PyObject *res = NULL;
@@ -1193,8 +1127,7 @@ typedef struct {
 } PythonCmd_ClientData;
 
 static int
-PythonCmd_Error(interp)
-	Tcl_Interp *interp;
+PythonCmd_Error(Tcl_Interp *interp)
 {
 	errorInCmd = 1;
 	PyErr_Fetch(&excInCmd, &valInCmd, &trbInCmd);
@@ -1206,11 +1139,7 @@ PythonCmd_Error(interp)
  * function or method.
  */
 static int
-PythonCmd(clientData, interp, argc, argv)
-	ClientData clientData;
-	Tcl_Interp *interp;
-	int argc;
-	char *argv[];
+PythonCmd(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[])
 {
 	PythonCmd_ClientData *data = (PythonCmd_ClientData *)clientData;
 	PyObject *self, *func, *arg, *res, *tmp;
@@ -1256,8 +1185,7 @@ PythonCmd(clientData, interp, argc, argv)
 }
 
 static void
-PythonCmdDelete(clientData)
-	ClientData clientData;
+PythonCmdDelete(ClientData clientData)
 {
 	PythonCmd_ClientData *data = (PythonCmd_ClientData *)clientData;
 
@@ -1271,9 +1199,7 @@ PythonCmdDelete(clientData)
 
 
 static PyObject *
-Tkapp_CreateCommand(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_CreateCommand(PyObject *self, PyObject *args)
 {
 	PythonCmd_ClientData *data;
 	char *cmdName;
@@ -1312,9 +1238,7 @@ Tkapp_CreateCommand(self, args)
 
 
 static PyObject *
-Tkapp_DeleteCommand(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_DeleteCommand(PyObject *self, PyObject *args)
 {
 	char *cmdName;
 	int err;
@@ -1347,10 +1271,7 @@ typedef struct _fhcdata {
 static FileHandler_ClientData *HeadFHCD;
 
 static FileHandler_ClientData *
-NewFHCD(func, file, id)
-	PyObject *func;
-	PyObject *file;
-	int id;
+NewFHCD(PyObject *func, PyObject *file, int id)
 {
 	FileHandler_ClientData *p;
 	p = PyMem_NEW(FileHandler_ClientData, 1);
@@ -1367,8 +1288,7 @@ NewFHCD(func, file, id)
 }
 
 static void
-DeleteFHCD(id)
-	int id;
+DeleteFHCD(int id)
 {
 	FileHandler_ClientData *p, **pp;
 	
@@ -1386,9 +1306,7 @@ DeleteFHCD(id)
 }
 
 static void
-FileHandler(clientData, mask)
-	ClientData clientData;
-	int mask;
+FileHandler(ClientData clientData, int mask)
 {
 	FileHandler_ClientData *data = (FileHandler_ClientData *)clientData;
 	PyObject *func, *file, *arg, *res;
@@ -1410,11 +1328,9 @@ FileHandler(clientData, mask)
 }
 
 static int
-GetFileNo(file)
-	/* Either an int >= 0 or an object with a
-	 *.fileno() method that returns an int >= 0
-	 */
-	PyObject *file;
+GetFileNo(PyObject *file) /* Either an int >= 0 or an object with
+			   * .fileno() method that returns an int >= 0
+			   */
 {
 	PyObject *meth, *args, *res;
 	int id;
@@ -1453,9 +1369,8 @@ GetFileNo(file)
 }
 
 static PyObject *
-Tkapp_CreateFileHandler(self, args)
-	PyObject *self;
-	PyObject *args;			     /* Is (file, mask, func) */
+Tkapp_CreateFileHandler(PyObject *self, PyObject *args)
+    /* Is (file, mask, func) */
 {
 	FileHandler_ClientData *data;
 	PyObject *file, *func;
@@ -1486,9 +1401,8 @@ Tkapp_CreateFileHandler(self, args)
 }
 
 static PyObject *
-Tkapp_DeleteFileHandler(self, args)
-	PyObject *self;
-	PyObject *args;			     /* Args: file */
+Tkapp_DeleteFileHandler(PyObject *self, PyObject *args)
+    /* Args: file */
 {
 	PyObject *file;
 	int id;
@@ -1524,9 +1438,7 @@ typedef struct {
 } TkttObject;
 
 static PyObject *
-Tktt_DeleteTimerHandler(self, args)
-	PyObject *self;
-	PyObject *args;
+Tktt_DeleteTimerHandler(PyObject *self, PyObject *args)
 {
 	TkttObject *v = (TkttObject *)self;
 	PyObject *func = v->func;
@@ -1553,8 +1465,7 @@ static PyMethodDef Tktt_methods[] =
 };
 
 static TkttObject *
-Tktt_New(func)
-	PyObject *func;
+Tktt_New(PyObject *func)
 {
 	TkttObject *v;
   
@@ -1572,8 +1483,7 @@ Tktt_New(func)
 }
 
 static void
-Tktt_Dealloc(self)
-	PyObject *self;
+Tktt_Dealloc(PyObject *self)
 {
 	TkttObject *v = (TkttObject *)self;
 	PyObject *func = v->func;
@@ -1584,8 +1494,7 @@ Tktt_Dealloc(self)
 }
 
 static PyObject *
-Tktt_Repr(self)
-	PyObject *self;
+Tktt_Repr(PyObject *self)
 {
 	TkttObject *v = (TkttObject *)self;
 	char buf[100];
@@ -1596,9 +1505,7 @@ Tktt_Repr(self)
 }
 
 static PyObject *
-Tktt_GetAttr(self, name)
-	PyObject *self;
-	char *name;
+Tktt_GetAttr(PyObject *self, char *name)
 {
 	return Py_FindMethod(Tktt_methods, self, name);
 }
@@ -1627,8 +1534,7 @@ static PyTypeObject Tktt_Type =
 /** Timer Handler **/
 
 static void
-TimerHandler(clientData)
-	ClientData clientData;
+TimerHandler(ClientData clientData)
 {
 	TkttObject *v = (TkttObject *)clientData;
 	PyObject *func = v->func;
@@ -1656,9 +1562,8 @@ TimerHandler(clientData)
 }
 
 static PyObject *
-Tkapp_CreateTimerHandler(self, args)
-	PyObject *self;
-	PyObject *args;			     /* Is (milliseconds, func) */
+Tkapp_CreateTimerHandler(PyObject *self, PyObject *args)
+    /* Is (milliseconds, func) */
 {
 	int milliseconds;
 	PyObject *func;
@@ -1681,9 +1586,7 @@ Tkapp_CreateTimerHandler(self, args)
 /** Event Loop **/
 
 static PyObject *
-Tkapp_MainLoop(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_MainLoop(PyObject *self, PyObject *args)
 {
 	int threshold = 0;
 #ifdef WITH_THREAD
@@ -1732,9 +1635,7 @@ Tkapp_MainLoop(self, args)
 }
 
 static PyObject *
-Tkapp_DoOneEvent(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_DoOneEvent(PyObject *self, PyObject *args)
 {
 	int flags = 0;
 	int rv;
@@ -1749,9 +1650,7 @@ Tkapp_DoOneEvent(self, args)
 }
 
 static PyObject *
-Tkapp_Quit(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_Quit(PyObject *self, PyObject *args)
 {
 
 	if (!PyArg_ParseTuple(args, ""))
@@ -1763,9 +1662,7 @@ Tkapp_Quit(self, args)
 }
 
 static PyObject *
-Tkapp_InterpAddr(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkapp_InterpAddr(PyObject *self, PyObject *args)
 {
 
 	if (!PyArg_ParseTuple(args, ""))
@@ -1774,6 +1671,49 @@ Tkapp_InterpAddr(self, args)
 	return PyInt_FromLong((long)Tkapp_Interp(self));
 }
 
+static PyObject *
+Tkapp_UTF8_to_Latin1 (PyObject *self, PyObject *args)
+#if TKMAJORMINOR < 8001
+{
+    PyObject * string;
+
+    if (!PyArg_ParseTuple(args, "S", &string))
+	return NULL;
+
+    Py_INCREF(string);
+    return string;
+}
+#else
+{
+    PyObject * utf8;
+    PyObject * latin1;
+    Tcl_DString dstring;
+    Tcl_Encoding encoding;
+
+    if (!PyArg_ParseTuple(args, "S", &utf8))
+	return NULL;
+
+    encoding = Tcl_GetEncoding(Tkapp_Interp(self), "iso8859-1");
+    if (!encoding)
+    {
+	/* encoding can't be found */
+	PyErr_SetString(PyExc_RuntimeError,
+			"Can't find Tcl's iso8859-1 encoding");
+	return NULL;
+    }
+    Tcl_UtfToExternalDString(encoding, PyString_AsString(utf8),
+			     PyString_Size(utf8), &dstring);
+
+    latin1 = PyString_FromString(dstring.string);
+
+    Tcl_FreeEncoding(encoding);
+    Tcl_DStringFree(&dstring);
+
+    return latin1;
+}
+#endif
+
+
 
 
 /**** Tkapp Method List ****/
@@ -1814,6 +1754,7 @@ static PyMethodDef Tkapp_methods[] =
 	{"dooneevent", 	       Tkapp_DoOneEvent, 1},
 	{"quit", 	       Tkapp_Quit, 1},
 	{"interpaddr",         Tkapp_InterpAddr, 1},
+	{"utf8_to_latin1",     Tkapp_UTF8_to_Latin1, 1},
 	{NULL, 		       NULL}
 };
 
@@ -1822,8 +1763,7 @@ static PyMethodDef Tkapp_methods[] =
 /**** Tkapp Type Methods ****/
 
 static void
-Tkapp_Dealloc(self)
-	PyObject *self;
+Tkapp_Dealloc(PyObject *self)
 {
 	ENTER_TCL
 	Tcl_DeleteInterp(Tkapp_Interp(self));
@@ -1833,9 +1773,7 @@ Tkapp_Dealloc(self)
 }
 
 static PyObject *
-Tkapp_GetAttr(self, name)
-	PyObject *self;
-	char *name;
+Tkapp_GetAttr(PyObject *self, char *name)
 {
 	return Py_FindMethod(Tkapp_methods, self, name);
 }
@@ -1864,9 +1802,7 @@ static PyTypeObject Tkapp_Type =
 /**** Tkinter Module ****/
 
 static PyObject *
-Tkinter_Create(self, args)
-	PyObject *self;
-	PyObject *args;
+Tkinter_Create(PyObject *self, PyObject *args)
 {
 	char *screenName = NULL;
 	char *baseName = NULL;
@@ -1909,9 +1845,7 @@ static int stdin_ready = 0;
 
 #ifndef MS_WINDOWS
 static void
-MyFileProc(clientData, mask)
-	void *clientData;
-	int mask;
+MyFileProc(void *clientData, int mask)
 {
 	stdin_ready = 1;
 }
@@ -1922,7 +1856,7 @@ static PyThreadState *event_tstate = NULL;
 #endif
 
 static int
-EventHook()
+EventHook(void)
 {
 #ifndef MS_WINDOWS
 	FHANDLE tfile;
@@ -1981,7 +1915,7 @@ EventHook()
 #endif
 
 static void
-EnableEventHook()
+EnableEventHook(void)
 {
 #ifdef WAIT_FOR_STDIN
 	if (PyOS_InputHook == NULL) {
@@ -1994,7 +1928,7 @@ EnableEventHook()
 }
 
 static void
-DisableEventHook()
+DisableEventHook(void)
 {
 #ifdef WAIT_FOR_STDIN
 	if (Tk_GetNumMainWindows() == 0 && PyOS_InputHook == EventHook) {
@@ -2006,10 +1940,7 @@ DisableEventHook()
 
 /* all errors will be checked in one fell swoop in init_tkinter() */
 static void
-ins_long(d, name, val)
-	PyObject *d;
-	char *name;
-	long val;
+ins_long(PyObject *d, char *name, long val)
 {
 	PyObject *v = PyInt_FromLong(val);
 	if (v) {
@@ -2018,10 +1949,7 @@ ins_long(d, name, val)
 	}
 }
 static void
-ins_string(d, name, val)
-	PyObject *d;
-	char *name;
-	char *val;
+ins_string(PyObject *d, char *name, char *val)
 {
 	PyObject *v = PyString_FromString(val);
 	if (v) {
@@ -2032,7 +1960,7 @@ ins_string(d, name, val)
 
 
 void
-initpaxtkinter() /* function name changed for pax */
+initpaxtkinter(void) /* function name changed for pax */
 {
 	PyObject *m, *d;
 
@@ -2127,8 +2055,7 @@ panic(char * format, ...)
 */
 
 static int
-PyMacConvertEvent(eventPtr)
-	EventRecord *eventPtr;
+PyMacConvertEvent(EventRecord *eventPtr)
 {
 	WindowPtr frontwin;
 	/*
@@ -2159,11 +2086,10 @@ PyMacConvertEvent(eventPtr)
  * for other versions.  */
 
 int
-Tcl_FileReady(file, mask)
-    Tcl_File file;		/* File handle for a stream. */
-    int mask;			/* OR'ed combination of TCL_READABLE,
-				 * TCL_WRITABLE, and TCL_EXCEPTION:
-				 * indicates conditions caller cares about. */
+Tcl_FileReady(Tcl_File file, /* File handle for a stream. */
+	      int mask)      /* OR'ed combination of TCL_READABLE,
+			      * TCL_WRITABLE, and TCL_EXCEPTION,
+			      * indicates conditions caller cares about. */
 {
     int type;
     int fd;
