@@ -1,5 +1,6 @@
 # Sketch - A Python-based interactive drawing program
-# Copyright (C) 1997, 1998, 1999, 2000 by Bernhard Herzog
+# Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002 by Bernhard Herzog
+# Some code for Text elements contributed by Paul Giotta (2002)
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,6 +31,7 @@ import os, sys
 import re
 from string import strip, split, atoi, lower
 import string
+import operator
 
 import streamfilter
 
@@ -38,12 +40,14 @@ from Sketch import Document, Layer, CreatePath, ContSmooth, \
      CreateRGBColor, CreateCMYKColor, MultiGradient, \
      Trafo, Translation, Rotation, Scale, Point, Polar, \
      StandardColors, GetFont, PathText, SimpleText, const, UnionRects, \
-     Bezier, Line
+     Bezier, Line, load_image, skread
 
 from Sketch.warn import INTERNAL, USER, warn_tb
 
 from Sketch.load import GenericLoader, EmptyCompositeError
 
+from Sketch.Graphics import text
+
 try:
     from xml.sax import saxlib, saxexts
 except ImportError:
@@ -52,25 +56,25 @@ except ImportError:
             "See the README for more information.")
     raise
 
+# beginning with Python 2.0, the XML modules return Unicode strings,
+# while for older versions they're 'normal' 8-bit strings. Provide some
+# functions to make this code work with both strig types.
 
+def as_latin1(s):
+    # convert the string s to iso-latin-1 if it's a unicode string
+    encode = getattr(s, "encode", None)
+    if encode is not None:
+        s = encode("iso-8859-1", "replace")
+    return s
+
+
+# Conversion factors to convert standard CSS/SVG units to userspace
+# units.
 factors = {'pt': 1.0, 'px': 1.0, 'in': 72.0,
            'cm': 72.0 / 2.54, 'mm': 7.20 / 2.54}
 
 degrees = pi / 180.0
 
-def length(str):
-    str = strip(str)
-    factor = factors.get(str[-2:])
-    if factor is not None:
-        str = str[:-2]
-    elif str[-1] == '%':
-        str = str[:-1]
-        factor = 0.01
-    else:
-        factor = 1.0
-    return float(str) * factor
-
-
 
 def csscolor(str):
     str = strip(str)
@@ -80,9 +84,12 @@ def csscolor(str):
             g = atoi(str[3:5], 16) / 255.0
             b = atoi(str[5:7], 16) / 255.0
         elif len(str) == 4:
-            r = atoi(str[1], 16) / 16.0
-            g = atoi(str[2], 16) / 16.0
-            b = atoi(str[3], 16) / 16.0
+            # According to the CSS rules a single HEX digit is to be
+            # treated as a repetition of the digit, so that for a digit
+            # d the value is (16 * d + d) / 255.0 which is equal to d / 15.0
+            r = atoi(str[1], 16) / 15.0
+            g = atoi(str[2], 16) / 15.0
+            b = atoi(str[3], 16) / 15.0
         color = CreateRGBColor(r, g, b)
     elif namedcolors.has_key(str):
         color = namedcolors[str]
@@ -131,6 +138,8 @@ class SVGHandler(saxlib.HandlerBase):
                       'polyline': 'polyline',
                       'polygon': 'polygon',
                       'path':   'begin_path',
+                      'text':   'begin_text',
+                      'image':   'image',
                       'data':   'data',
                       'use':   'use',
                       'defs':   'begin_defs',
@@ -138,6 +147,7 @@ class SVGHandler(saxlib.HandlerBase):
     dispatch_end = {'g': 'end_group',
                     'path': 'end_path',
                     'defs': 'end_defs',
+                    'text': 'end_text'
                     }
     
     def __init__(self, loader):
@@ -147,6 +157,10 @@ class SVGHandler(saxlib.HandlerBase):
         self.style = loader.style.Copy()
         self.style.line_pattern = EmptyPattern
         self.style.fill_pattern = EmptyPattern
+        self.current_text = ""
+        self.style.font = GetFont("Times-Roman")
+        self.style.font_size = 12
+        self.halign = text.ALIGN_LEFT
         #SolidPattern(StandardColors.black)
         self.named_objects = {}
         self.in_defs = 0
@@ -166,6 +180,7 @@ class SVGHandler(saxlib.HandlerBase):
     def parse_transform(self, trafo_string):
         trafo = self.trafo
         #print trafo
+        trafo_string = as_latin1(trafo_string)
         while trafo_string:
             #print trafo_string
             match = rx_trafo.match(trafo_string)
@@ -200,6 +215,7 @@ class SVGHandler(saxlib.HandlerBase):
         self.push_state()
         if attrs.has_key('transform'):
             self.parse_transform(attrs['transform'])
+        self._print("applied transormation", self.trafo)
         method = self.dispatch_start.get(name)
         if method is not None:
             getattr(self, method)(attrs)
@@ -212,6 +228,9 @@ class SVGHandler(saxlib.HandlerBase):
             getattr(self, method)()
         self.pop_state()
 
+    def characters(self, ch, start, length):
+        self.current_text = self.current_text + as_latin1(ch)
+
     def error(self, exception):
         print 'error', exception
 
@@ -222,39 +241,62 @@ class SVGHandler(saxlib.HandlerBase):
         print 'warning', exception
 
     def initsvg(self, attrs):
-        width = length(attrs['width'])
-        height = length(attrs['height'])
+        width = self.user_length(attrs.get('width', '100%'))
+        height = self.user_length(attrs.get('height', '100%'))
         self._print('initsvg', width, height)
         self.trafo = Trafo(1, 0, 0, -1, 0, height)
         self.basetrafo = self.trafo
+        self._print("basetrafo", self.basetrafo)
 
     def parse_style(self, style):
         parts = filter(None, map(strip, split(style, ';')))
         for part in parts:
             key, val = map(strip, split(part, ':', 1))
             self._print('style', key, val)
-            if key == 'fill':
-                if val == 'none':
-                    self.style.fill_pattern = EmptyPattern
-                else:
-                    color = csscolor(val)
-                    self._print('fill', color)
-                    self.style.fill_pattern = SolidPattern(color)
-            elif key == 'stroke':
-                if val == 'none':
-                    self.style.line_pattern = EmptyPattern
-                else:
-                    color = csscolor(val)
-                    self._print('stroke', color)
-                    self.style.line_pattern = SolidPattern(color)
-            elif key == 'stroke-width':
-                width = length(val)
-                self._print('width', width)
-                self.style.line_width = width
-            elif key == 'stroke-linejoin':
-                self.style.line_join = join[val]
-            elif key == 'stroke-linecap':
-                self.style.line_cap = cap[val]
+
+            # only try to parse the value if it's not empty
+            if val:
+                self.try_add_style(key, val)
+            else:
+                # FIXME: we should probably print a message or something
+                pass
+            
+    def try_add_style(self,key,val):
+        if key == 'fill':
+            if val == 'none':
+                self.style.fill_pattern = EmptyPattern
+            else:
+                color = csscolor(val)
+                self._print('fill', color)
+                self.style.fill_pattern = SolidPattern(color)
+        elif key == 'stroke':
+            if val == 'none':
+                self.style.line_pattern = EmptyPattern
+            else:
+                color = csscolor(val)
+                self._print('stroke', color)
+                self.style.line_pattern = SolidPattern(color)
+        elif key == 'stroke-width':
+            width = self.user_length(val)
+            self._print('width', width)
+            self.style.line_width = width
+        elif key == 'stroke-linejoin':
+            self.style.line_join = join[val]
+        elif key == 'stroke-linecap':
+            self.style.line_cap = cap[val]
+        elif key == 'font-family':
+            self.style.font = GetFont(val)
+        elif key == 'font-size':
+            self.style.font_size = self.user_length(val)
+            ####self.style.font_size = float(val)
+        elif key == 'text-anchor':
+            if val=='start':
+              self.halign = text.ALIGN_LEFT
+            elif val == 'middle':
+              self.halign = text.ALIGN_CENTER
+            elif val == 'end':
+              self.halign = text.ALIGN_RIGHT
+
 
     def push_state(self):
         self.state_stack = self.style, self.trafo, self.state_stack
@@ -263,10 +305,32 @@ class SVGHandler(saxlib.HandlerBase):
     def pop_state(self):
         self.style, self.trafo, self.state_stack = self.state_stack
 
-    def point(self, x, y, relative = 0):
+    def user_length(self, str):
+        # interpret string as a length and return the appropriate value
+        # user coordinates
+        str = strip(str)
+        factor = factors.get(str[-2:])
+        if factor is not None:
+            str = str[:-2]
+        elif str[-1] == '%':
+            # FIXME: this case depends on the width/height attrs of the
+            # SVG element
+            str = str[:-1]
+            factor = 1.0
+        else:
+            factor = 1.0
+        return float(str) * factor
+
+    def user_point(self, x, y):
+        # Return the point described by the SVG coordinates x and y as
+        # an SKPoint object in user coordinates. x and y are expected to
+        # be strings.
         x = strip(x)
         y = strip(y)
-        
+
+        # extract the units from the coordinate values if any and
+        # determine the appropriate factor to convert those units to
+        # user space units.
         xunit = x[-2:]
         factor = factors.get(xunit)
         if factor is not None:
@@ -288,32 +352,29 @@ class SVGHandler(saxlib.HandlerBase):
         elif y[-1] == '%':
             y = y[:-1]
             yunit = '%'
-            factor = 0.01
+            factor = 1.0
         else:
             yunit = ''
             factor = 1.0
         y = float(y) * factor
 
-        if xunit:
-            if yunit:
-                if relative:
-                    p = self.basetrafo.DTransform(x, y)
-                else:
-                    p = self.basetrafo(x, y)
-            else:
-                # XXX ugly special case 
-                pass
+        return Point(x, y)
+
+
+    def point(self, x, y, relative = 0):
+        # Return the point described by the SVG coordinates x and y as
+        # an SKPoint object in absolute, i.e. document coordinates. x
+        # and y are expected to be strings. If relative is true, they're
+        # relative coordinates.
+        x, y = self.user_point(x, y)
+
+        if relative:
+            p = self.trafo.DTransform(x, y)
         else:
-            if yunit:
-                # XXX ugly special case 
-                pass
-            else:
-                if relative:
-                    p = self.trafo.DTransform(x, y)
-                else:
-                    p = self.trafo(x, y)
+            p = self.trafo(x, y)
         return p
 
+
     def circle(self, attrs):
         if self.in_defs:
             id = attrs.get('id', '')
@@ -395,7 +456,7 @@ class SVGHandler(saxlib.HandlerBase):
             if id:
                 self.named_objects[id] = ('object', 'polyline', attrs)
             return
-        points = attrs['points']
+        points = as_latin1(attrs['points'])
         points = string.translate(points, commatospace)
         points = split(points)
         path = CreatePath()
@@ -414,7 +475,7 @@ class SVGHandler(saxlib.HandlerBase):
             if id:
                 self.named_objects[id] = ('object', 'polygon', attrs)
             return
-        points = attrs['points']
+        points = as_latin1(attrs['points'])
         points = string.translate(points, commatospace)
         points = split(points)
         path = CreatePath()
@@ -433,7 +494,7 @@ class SVGHandler(saxlib.HandlerBase):
         paths = self.paths
         path = self.path
         trafo = self.trafo
-        str = strip(string.translate(str, commatospace))
+        str = strip(string.translate(as_latin1(str), commatospace))
         last_quad = None
         last_cmd = cmd = None
         f13 = 1.0 / 3.0; f23 = 2.0 / 3.0
@@ -449,7 +510,15 @@ class SVGHandler(saxlib.HandlerBase):
                 points = match.group(1)
                 #print '**', points
                 if points:
-                    points = map(float, split(points))
+                    # use tokenize_line to parse the arguments so that
+                    # we deal with signed numbers following another
+                    # number without intervening whitespace other
+                    # characters properls.
+                    # FIXME: tokenize_line works but is not the best way
+                    # to do it because it accepts input that wouldn't be
+                    # valid here.
+                    points = filter(operator.isNumberType,
+                                    skread.tokenize_line(points))
                 #print cmd, points
                 if cmd in 'mM':
                     path = CreatePath()
@@ -605,6 +674,11 @@ class SVGHandler(saxlib.HandlerBase):
         self.path = path
 
     def begin_path(self, attrs):
+        if self.in_defs:
+            id = attrs.get('id', '')
+            if id:
+                self.named_objects[id] = ('object', 'path', attrs)
+            return
         self.paths = []
         self.path = None
         self.parse_path(attrs['d'])
@@ -614,9 +688,77 @@ class SVGHandler(saxlib.HandlerBase):
         self.loader.style = self.style
         
     def end_path(self):
+        if self.in_defs:
+            return
         self.loader.bezier(paths = tuple(self.paths))
         self.paths = None
         
+    def image(self, attrs):
+        if self.in_defs:
+            id = attrs.get('id', '')
+            if id:
+                self.named_objects[id] = ('object', 'image', attrs)
+            return
+        href = as_latin1(attrs['xlink:href'])
+        image = load_image(os.path.join(self.loader.directory, href)).image
+        if attrs.has_key('x'):
+            x = attrs['x']
+        else:
+            x = '0'
+        if attrs.has_key('y'):
+            y = attrs['y']
+        else:
+            y = '0'
+        x, y = self.user_point(x, y)
+        
+        width = self.user_length(attrs['width'])
+        scalex =  width / image.size[0]
+
+        height = self.user_length(attrs['height']) 
+        scaley = -height / image.size[1]
+
+        style = attrs.get('style', '')
+        if style:
+            self.parse_style(style)
+        self.loader.style = self.style
+        t = self.trafo(Trafo(scalex, 0, 0, scaley, x, y + height))
+        self._print('image', t)
+        self.loader.image(image, t)
+
+    def begin_text(self, attrs):
+        if self.in_defs:
+            id = attrs.get('id', '')
+            if id:
+                self.named_objects[id] = ('object', 'text', attrs)
+            return
+
+        # parse the presentation attributes if any.
+        # FIXME: this has to be implemented for the other elements that
+        # can have presentation attributes as well.
+        for key,value in attrs.items():
+            self.try_add_style(key,value)
+            
+        if attrs.has_key('x'):
+            x = attrs['x']
+        else:
+            x = '0'
+        if attrs.has_key('y'):
+            y = attrs['y']
+        else:
+            y = '0'
+        x, y = self.user_point(x, y)
+        self.text_trafo = self.trafo(Trafo(1, 0, 0, -1, x, y))
+        self._print('text', self.text_trafo)
+        style = attrs.get('style', '')
+        if style:
+            self.parse_style(style)
+        self.loader.style = self.style
+        self.current_text=''
+
+    def end_text(self):
+        self.loader.simple_text(strip(self.current_text), self.text_trafo,
+                                halign = self.halign)
+
     def data(self, attrs):
         pass
 
@@ -640,7 +782,6 @@ class SVGHandler(saxlib.HandlerBase):
             name = attrs.get('href', '<none>')
         if name:
             data = self.named_objects.get(name[1:])
-            #print name, data
             if data[0] == 'object':
                 if attrs.has_key('style'):
                     self.parse_style(attrs['style'])
@@ -659,10 +800,14 @@ class SVGLoader(GenericLoader):
     format_name = format_name
 
     def __init__(self, file, filename, match):
-	GenericLoader.__init__(self, file, filename, match)
+        GenericLoader.__init__(self, file, filename, match)
+        if self.filename:
+            self.directory = os.path.split(filename)[0]
+        else:
+            self.directory = ''
         
     def __del__(self):
-	pass
+        pass
 
     def Load(self):
         try:
