@@ -1,5 +1,5 @@
 # Sketch - A Python-based interactive drawing program
-# Copyright (C) 1997, 1998, 1999 by Bernhard Herzog
+# Copyright (C) 1997, 1998, 1999, 2000 by Bernhard Herzog
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -15,7 +15,7 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	USA
 
-from math import pi, floor
+from math import pi, floor, atan2, ceil
 
 from traceback import print_stack
 
@@ -147,7 +147,7 @@ class PolyBezier(Primitive):
 	    if t is not None:
 		#print p, t
 		p2 = path.point_at(t)
-		found.append(abs(p - p2), p2)
+		found.append((abs(p - p2), p2))
 	return min(found)
 
     def update_rects(self):
@@ -434,11 +434,12 @@ class PolyBezierEditor(Editor):
             t = path.nearest_point(p.x, p.y)
 	    if t is not None:
 		p2 = path.point_at(t)
-		found.append(abs(p - p2), i, t, p2)
+		found.append((abs(p - p2), i, t, p2))
         dist, i, t, p2 = min(found)
         self.selected_path = i
         self.selected_idx = t
         self.selection_type = SelCurvePoint
+        return 1
 
     def SelectHandle(self, handle, mode = SelectSet):
         path_idx, segment = handle.code
@@ -522,16 +523,47 @@ class PolyBezierEditor(Editor):
 		p2 = path.Segment(segment)[1][1]
 		self.DragStart(p2)
 		return p - p2
-            # else self.selection_type == SelCurvePoint ?
+            elif self.selection_type == SelCurvePoint:
+                start = path.point_at(self.selected_idx)
+                segment = ceil(self.selected_idx)
+                prev = next = -1
+                type = path.SegmentType(segment)
+                if type == Bezier:
+                    if path.Continuity(segment):
+                        if segment < path.len - 1 \
+                           and path.SegmentType(segment + 1) == Bezier:
+                            next = segment + 1
+                        elif path.closed and segment == path.len - 1 \
+                             and path.SegmentType(1) == Bezier:
+                            next = 1
+                    if segment > 1 \
+                       and path.SegmentType(segment - 1) == Bezier\
+                       and path.Continuity(segment - 1):
+                        prev = segment - 1
+                    elif path.closed and segment == 1 \
+                         and path.SegmentType(-1) == Bezier\
+                         and path.Continuity(-1):
+                        prev = path.len - 1
+                else:
+                    if segment < path.len - 1:
+                        next = segment + 1
+                    elif path.closed and segment == path.len - 1:
+                        next = 1
+                    if segment >= 1:
+                        prev = segment - 1
+                    elif path.closed and segment == 1:
+                        prev = path.len - 1
+                self.other_segment = (prev, next)
+		self.DragStart(start)
+		return p - start
 
     def apply_constraints(self, p, state):
         if state & ConstraintMask:
             if self.selection_type == SelNodes:
-                off = p - self.drag_start
-		if abs(off.x) > abs(off.y):
-		    p = Point(p.x, self.drag_start.y)
-		else:
-		    p = Point(self.drag_start.x, p.y)
+		pi4 = pi / 4
+		off = p - self.drag_start
+                d = Polar(pi4 * round(atan2(off.y, off.x) / pi4))
+                p = self.drag_start + (off * d) * d
             elif self.selection_type in (SelSegmentFirst, SelSegmentLast):
                 path = self.paths[self.selected_path]
                 if self.selection_type == SelSegmentFirst:
@@ -585,7 +617,50 @@ class PolyBezierEditor(Editor):
 		    path.SetBezier(other, p1, p2, node2, cont2)
 		path.SelectSegment(segment)
 	    return self.set_paths(paths) # set_paths calls _changed()
-        # else self.selection_type == SelCurvePoint ?
+        elif self.selection_type == SelCurvePoint:
+            idx = self.selected_path
+            path = self.paths[idx].Duplicate()
+            paths = self.paths[:idx] + (path,) + self.paths[idx + 1:]
+
+            segment = int(self.selected_idx)
+            t = self.selected_idx - segment
+            type, control, node, cont = path.Segment(segment + 1)
+            if type == Bezier:
+                p1, p2 = control
+                if t <= 0.5:
+                    alpha = ((t * 2) ** 3) / 2
+                else:
+                    alpha = 1 - (((1 - t) * 2) ** 3) / 2
+
+                p1 = p1 + (self.off / (3 * t * (1 - t)**2)) * (1 - alpha)
+                p2 = p2 + (self.off / (3 * t**2 * (1 - t))) * alpha
+
+                path.SetBezier(segment + 1, p1, p2, node, cont)
+            else:
+                path.SetLine(segment + 1, node + self.off, cont)
+            prev, next = self.other_segment
+            if prev >= 0:
+                _type, _control, _node, _cont = path.Segment(prev)
+                if _type == Bezier:
+                    _p1, _p2 = _control
+                    if type == Bezier:
+                        _p2 = adjust_control_point(_p2, _node, p1, _cont)
+                    else:
+                        _p2 = _p2 + self.off
+                        _node = _node + self.off
+                    path.SetBezier(prev, _p1, _p2, _node, _cont)
+                else:
+                    path.SetLine(prev, _node + self.off, _cont)
+            if next >= 0:
+                _type, _control, _node, _cont = path.Segment(next)
+                if _type == Bezier:
+                    _p1, _p2 = _control
+                    if type == Bezier:
+                        _p1 = adjust_control_point(_p1, node, p2, cont)
+                    else:
+                        _p1 = _p1 + self.off
+                    path.SetBezier(next, _p1, _p2, _node, _cont)
+            return self.set_paths(paths) # set_paths calls _changed()
 
     def DrawDragged(self, device, partially):
 	if self.selection_type == SelNodes:
@@ -627,6 +702,59 @@ class PolyBezierEditor(Editor):
 		device.Bezier(node, p1, p2, node2)
 		device.DrawSmallRectHandle(p1)
 		device.DrawHandleLine(node, p1)
+        elif self.selection_type == SelCurvePoint:
+            path = self.paths[self.selected_path]
+            segment = int(self.selected_idx)
+            t = self.selected_idx - segment
+            prevnode = path.Node(segment)
+            
+            type, control, node, cont = path.Segment(segment + 1)
+            if type == Bezier:
+                p1, p2 = control
+                if t <= 0.5:
+                    alpha = ((t * 2) ** 3) / 2
+                else:
+                    alpha = 1 - (((1 - t) * 2) ** 3) / 2
+
+                p1 = p1 + (self.off / (3 * t * (1 - t)**2)) * (1 - alpha)
+                p2 = p2 + (self.off / (3 * t**2 * (1 - t))) * alpha
+
+                device.Bezier(prevnode, p1, p2, node)
+                device.DrawSmallRectHandle(p1)
+                device.DrawHandleLine(prevnode, p1)
+                device.DrawSmallRectHandle(p2)
+                device.DrawHandleLine(node, p2)
+            else:
+                device.DrawLine(prevnode + self.off, node + self.off)
+            prev, next = self.other_segment
+            if prev > 0:
+                _type, _control, _node, _cont = path.Segment(prev)
+                if _type == Bezier:
+                    _p1, _p2 = _control
+                    if type == Bezier:
+                        _p2 = adjust_control_point(_p2, _node, p1, _cont)
+                        device.Bezier(path.Node(prev - 1), _p1, _p2, _node)
+                        device.DrawSmallRectHandle(_p2)
+                        device.DrawHandleLine(_node, _p2)
+                    else:
+                        device.Bezier(path.Node(prev - 1), _p1, _p2 + self.off,
+                                      _node + self.off)
+                else:
+                    device.DrawLine(path.Node(prev - 1), _node + self.off)
+            if next >= 0:
+                _type, _control, _node, _cont = path.Segment(next)
+                if _type == Bezier:
+                    _p1, _p2 = _control
+                    if type == Bezier:
+                        _p1 = adjust_control_point(_p1, node, p2, cont)
+                        device.Bezier(node, _p1, _p2, _node)
+                        device.DrawSmallRectHandle(_p1)
+                        device.DrawHandleLine(node, _p1)
+                    else:
+                        device.Bezier(node + self.off, _p1 + self.off, _p2,
+                                      _node)
+                else:
+                    device.DrawLine(node + self.off, _node)
 
     def GetHandles(self):
         NodeHandle = handle.MakeNodeHandle
@@ -924,7 +1052,8 @@ class PolyBezierEditor(Editor):
     def ChangeRect(self):
 	prop = self.properties
 	if prop.IsAlgorithmicFill() or prop.IsAlgorithmicLine() \
-	   or prop.line_arrow1 is not None or prop.line_arrow2 is not None:
+	   or prop.line_arrow1 is not None or prop.line_arrow2 is not None \
+           or self.selection_type == SelCurvePoint:
 	    return self.bounding_rect
 
 	filled = self.Filled()
