@@ -1,5 +1,5 @@
 # Sketch - A Python-based interactive drawing program
-# Copyright (C) 1996, 1997, 1998, 1999 by Bernhard Herzog
+# Copyright (C) 1996, 1997, 1998, 1999, 2000 by Bernhard Herzog
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -677,7 +677,10 @@ class EditDocument(SketchDocument, QueueingPublisher):
 		selinfo = []
 		for object in objects:
 		    selinfo.append(object.SelectionInfo())
-		self.__set_selection(selinfo, mode)
+                if selinfo:
+                    self.__set_selection(selinfo, mode)
+                else:
+                    self.__set_selection(None, SelectSet)
 	    except:
 		self.abort_transaction()
 	finally:
@@ -1387,6 +1390,16 @@ class EditDocument(SketchDocument, QueueingPublisher):
 	    copies = Group(copies)
 	else:
 	    copies = copies[0]
+            # This is ugly: Special case for internal path text objects.
+            # If the internal path text object is the only selected
+            # object, turn the copy into a normal simple text object.
+            # Thsi avoids some of the problems when you "Copy" an
+            # internal path text.
+            import text
+            if copies.is_PathTextText:
+                properties = copies.Properties().Duplicate()
+                copies = text.SimpleText(text = copies.Text(),
+                                         properties = properties)
 
 	copies.UntieFromDocument()
 	copies.SetDocument(None)
@@ -2057,7 +2070,7 @@ class EditDocument(SketchDocument, QueueingPublisher):
 		    i = idx + 1
 		elif i == idx + 1:
 		    i = idx
-		newsel.append(i, info)
+		newsel.append((i, info))
 	    self.__set_selection(selinfo.tree_to_list(newsel), SelectSet)
 	    self.queue_layer(LAYER_ORDER, layer, other)
 	    return (self._move_layer_down, idx + 1)
@@ -2079,7 +2092,7 @@ class EditDocument(SketchDocument, QueueingPublisher):
 		    i = idx - 1
 		elif i == idx - 1:
 		    i = idx
-		newsel.append(i, info)
+		newsel.append((i, info))
 	    self.__set_selection(selinfo.tree_to_list(newsel), SelectSet)
 	    self.queue_layer(LAYER_ORDER, layer, other)
 	    return (self._move_layer_up, idx - 1)
@@ -2122,7 +2135,7 @@ class EditDocument(SketchDocument, QueueingPublisher):
 		continue
 	    elif i > idx:
 		i = i - 1
-	    newsel.append(i, info)
+	    newsel.append((i, info))
 	self.__set_selection(selinfo.tree_to_list(newsel), SelectSet)
 
 	self.queue_layer(LAYER_ORDER, layer)
