@@ -1,5 +1,5 @@
 /* Sketch - A Python-based interactive drawing program
- * Copyright (C) 1997, 1998, 1999, 2000 by Bernhard Herzog
+ * Copyright (C) 1997, 1998, 1999, 2000, 2001 by Bernhard Herzog
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -490,6 +490,13 @@ curve_set_continuity(SKCurveObject * self, PyObject * args)
 int
 SKCurve_AppendSegment(SKCurveObject * self, CurveSegment * segment)
 {
+    if (self->len == 0 && segment->type == CurveBezier)
+    {
+	PyErr_SetString(PyExc_TypeError,
+			"The first segment added to a curve must be a line");
+	return 0;
+    }
+    
     if (!curve_grow(self, 1))
 	return 0;
 
