@@ -1,5 +1,5 @@
 /* Sketch - A Python-based interactive drawing program
- * Copyright (C) 1997, 1998, 1999 by Bernhard Herzog
+ * Copyright (C) 1997, 1998, 1999, 2000, 2001 by Bernhard Herzog
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -39,7 +39,7 @@ static int skcolor_allocated = 0;
 #define BLOCK_SIZE	1000	/* 1K less typical malloc overhead */
 #define N_COLOROBJECTS	(BLOCK_SIZE / sizeof(SKColorObject))
 static SKColorObject *
-fill_free_list()
+fill_free_list(void)
 {
     SKColorObject *p, *q;
     p = PyMem_NEW(SKColorObject, N_COLOROBJECTS);
@@ -484,10 +484,14 @@ skvisual_pseudocolor_free(SKVisualObject * self)
 	}
 	PyMem_DEL(self->dither_matrix);
     }
-    PyMem_XDEL(self->dither_red);
-    PyMem_XDEL(self->dither_green);
-    PyMem_XDEL(self->dither_blue);
-    PyMem_XDEL(self->dither_gray);
+    if (self->dither_red)
+	PyMem_DEL(self->dither_red);
+    if (self->dither_green)
+	PyMem_DEL(self->dither_green);
+    if (self->dither_blue)
+	PyMem_DEL(self->dither_blue);
+    if (self->dither_gray)
+	PyMem_DEL(self->dither_gray);
 }
 
 static int
