@@ -1,5 +1,5 @@
 /* Sketch - A Python-based interactive drawing program
- * Copyright (C) 1997, 1998, 1999 by Bernhard Herzog
+ * Copyright (C) 1997, 1998, 1999, 2001 by Bernhard Herzog
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -58,7 +58,7 @@ static int allocated = 0;
 #define N_RECTOBJECTS	(BLOCK_SIZE / sizeof(SKRectObject))
 
 static SKRectObject *
-fill_free_list()
+fill_free_list(void)
 {
     SKRectObject *p, *q;
     p = PyMem_NEW(SKRectObject, N_RECTOBJECTS);
@@ -127,8 +127,17 @@ skrect_compare(SKRectObject * v, SKRectObject * w)
 {
     int result;
 
+    /* In Python 2.1 (and probably later), the interpreter doesn't take
+     * a shortcut anymore when comparing and object to itself (in
+     * earlier versions an object was always equal to itself. Now we
+     * have to take care of that special case here too. */
+    if (v == w) return 0;
+
+    /* The EmptyRect is smaller than any other rect. */
     if (v == SKRect_EmptyRect)	return -1;
     if (w == SKRect_EmptyRect)	return +1;
+
+    /* The InfinityRect is larger than any other rect */
     if (v == SKRect_InfinityRect)	return +1;
     if (w == SKRect_InfinityRect)	return -1;
 
@@ -429,12 +438,12 @@ static struct memberlist skrect_memberlist[] = {
 
 
 static struct PyMethodDef skrect_methods[] = {
-    {"contains_point",	(PyCFunction)skrect_contains_point,	1},
-    {"contains_rect",	(PyCFunction)skrect_contains_rect,	1},
-    {"overlaps",	(PyCFunction)skrect_overlaps,		1},
-    {"grown",		(PyCFunction)skrect_grown,		1},
-    {"center",		(PyCFunction)skrect_center,		1},
-    {"translated",	(PyCFunction)skrect_translated,		1},
+    {"contains_point",	(PyCFunction)skrect_contains_point,	METH_VARARGS},
+    {"contains_rect",	(PyCFunction)skrect_contains_rect,	METH_VARARGS},
+    {"overlaps",	(PyCFunction)skrect_overlaps,		METH_VARARGS},
+    {"grown",		(PyCFunction)skrect_grown,		METH_VARARGS},
+    {"center",		(PyCFunction)skrect_center,		METH_VARARGS},
+    {"translated",	(PyCFunction)skrect_translated,		METH_VARARGS},
     {NULL,	NULL}
 };
 
